@@ -17,9 +17,8 @@ from horus.interfaces   import IHorusResetPasswordForm
 from horus.interfaces   import IHorusResetPasswordSchema
 from horus.interfaces   import IHorusProfileForm
 from horus.interfaces   import IHorusProfileSchema
-from horus.routes       import build_routes
 from horus.lib          import get_user
-from horus.lib          import get_class_from_config
+from hem.config         import get_class_from_config
 
 def groupfinder(userid, request):
     user = request.user
@@ -72,5 +71,5 @@ def includeme(config):
         if not config.registry.queryUtility(form):
             config.registry.registerUtility(SubmitForm, form)
 
-    config.include(build_routes)
-    config.scan('horus')
+    config.include('horus.routes')
+    config.scan()
