@@ -313,7 +313,7 @@ class TestRegisterController(UnitTestBase):
         schema = Mock()
         form = Mock()
         
-        self.config.registry.settings['su.require_activation'] = False
+        self.config.registry.settings['horus.require_activation'] = False
         self.config.registry.registerUtility(schema, IHorusRegisterSchema)
         self.config.registry.registerUtility(form, IHorusRegisterForm)
 
@@ -477,7 +477,7 @@ class TestRegisterController(UnitTestBase):
         from horus.views import RegisterController
         from pyramid_mailer.mailer import DummyMailer
         from pyramid_mailer.interfaces import IMailer
-        from horus.interfaces import IHorusSession
+        from hem.interfaces import IDBSession
         from horus.events import NewRegistrationEvent
         from horus.interfaces           import IHorusUserClass
         from horus.tests.models         import User
@@ -491,11 +491,11 @@ class TestRegisterController(UnitTestBase):
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         self.config.add_route('index', '/')
-        self.config.registry.settings['su.require_activation'] = False
+        self.config.registry.settings['horus.require_activation'] = False
 
         def handle_registration(event):
             request = event.request
-            session = request.registry.getUtility(IHorusSession)
+            session = request.registry.getUtility(IDBSession)
             session.commit()
 
         self.config.add_subscriber(handle_registration, NewRegistrationEvent)
@@ -650,7 +650,7 @@ class TestRegisterController(UnitTestBase):
 
         activations = Activation.get_all(request)
 
-        assert len(activations) == 1
+        assert len(activations.all()) == 1
         assert user.is_activated
         assert response.status_int == 302
 
@@ -881,7 +881,7 @@ class TestForgotPasswordController(UnitTestBase):
 
     def test_reset_password_valid_user(self):
         from horus.views import ForgotPasswordController
-        from horus.interfaces import IHorusSession
+        from hem.interfaces import IDBSession
         from horus.events import PasswordResetEvent
         from pyramid_mailer.interfaces import IMailer
         from pyramid_mailer.mailer import DummyMailer
@@ -925,7 +925,7 @@ class TestForgotPasswordController(UnitTestBase):
 
         def handle_password_reset(event):
             request = event.request
-            session = request.registry.getUtility(IHorusSession)
+            session = request.registry.getUtility(IDBSession)
             session.commit()
 
         self.config.add_subscriber(handle_password_reset, PasswordResetEvent)
@@ -1177,7 +1177,7 @@ class TestProfileController(UnitTestBase):
 
     def test_profile_update_profile(self):
         from horus.views import ProfileController
-        from horus.interfaces import IHorusSession
+        from hem.interfaces import IDBSession
         from horus.events import ProfileUpdatedEvent
         from horus.models import crypt
         from horus.interfaces           import IHorusUserClass
@@ -1198,7 +1198,7 @@ class TestProfileController(UnitTestBase):
 
         def handle_profile_updated(event):
             request = event.request
-            session = request.registry.getUtility(IHorusSession)
+            session = request.registry.getUtility(IDBSession)
             session.commit()
 
         self.config.add_subscriber(handle_profile_updated, ProfileUpdatedEvent)
@@ -1227,7 +1227,7 @@ class TestProfileController(UnitTestBase):
 
     def test_profile_update_password(self):
         from horus.views import ProfileController
-        from horus.interfaces import IHorusSession
+        from hem.interfaces import IDBSession
         from horus.events import ProfileUpdatedEvent
         from horus.models import crypt
         from horus.interfaces           import IHorusUserClass
@@ -1249,7 +1249,7 @@ class TestProfileController(UnitTestBase):
 
         def handle_profile_updated(event):
             request = event.request
-            session = request.registry.getUtility(IHorusSession)
+            session = request.registry.getUtility(IDBSession)
             session.commit()
 
         self.config.add_subscriber(handle_profile_updated, ProfileUpdatedEvent)
